@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: LMSDB_driver_postgres.class.php,v 1.17 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: LMSDB_driver_postgres.class.php,v 1.18 2004/03/11 18:37:15 lukasz Exp $
  */
 
 /*
@@ -35,7 +35,7 @@ class LMSDB_driver_postgres extends LMSDB_common
 
 	function LMSDB_driver_postgres($dbhost,$dbuser,$dbpasswd,$dbname)
 	{
-		$this->_version .= ' (core: '.eregi_replace('^.Revision: ([0-9.]+).*','\1',$this->_revision).' / driver: '.$this->_dbtype.' '.eregi_replace('^.Revision: ([0-9.]+).*','\1','$Revision: 1.17 $').')';
+		$this->_version .= ' (core: '.eregi_replace('^.Revision: ([0-9.]+).*','\1',$this->_revision).' / driver: '.$this->_dbtype.' '.eregi_replace('^.Revision: ([0-9.]+).*','\1','$Revision: 1.18 $').')';
 		$this->Connect($dbhost,$dbuser,$dbpasswd,$dbname);
 	}
 
@@ -59,27 +59,30 @@ class LMSDB_driver_postgres extends LMSDB_common
 			$this->_dbhost = $dbhost;
 			$this->_dbuser = $dbuser;
 			$this->_dbname = $dbname;
-			return $this->_dblink;
+			$this->_error = FALSE;
 		}
 		else
-			return FALSE;
+			$this->_error = TRUE;
+		return $this->_dblink;
 	}
 
 	function _driver_disconnect()
 	{
 		return pg_close($this->_dblink);
 	}
+
+	function _driver_geterror()
+	{
+		return pg_last_error($this->_dblink);
+	}
 	
 	function _driver_execute($query)
 	{
+		$this->_query = $query;
 		if($this->_result = pg_query($this->_dblink,$query))
-		{
-			$this->_query = $query;
 			$this->_error = FALSE;
-		}
 		else
-			$this->_error = pg_last_error($this->_dblink);
-
+			$this->_error = TRUE;
 		return $this->_result;
 	}
 
