@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: accesstable.php,v 1.23 2004/03/14 22:16:33 alec Exp $
+ *  $Id: accesstable.php,v 1.25 2004/04/26 20:18:20 alec Exp $
  */
 
 // lista moduw ktre zawsze s dostpne dla kadego
@@ -32,7 +32,7 @@ $access[table][0][name]		= "peen dostp";
 $access[table][0][allow_reg]	= "^.*$";
 
 $access[table][1][name]		= "odczyt wszystkich danych";
-$access[table][1][allow_reg]	= "^((admin|balance|db|net|node|netdev|tariff|payment|user)(list|list(debt|disc)|info|view|debt|search|balance)|netdevmap|print)$";
+$access[table][1][allow_reg]	= "^((admin|balance|db|net|node|netdev|tariff|payment|user|usergroup)(list|info|view|search|balance)|netdevmap|print)$";
 
 $access[table][2][name]		= "wczanie i odczanie komputerw";
 $access[table][2][allow_reg]	= "^nodeset$";
@@ -44,10 +44,10 @@ $access[table][4][name]         = "przeadowywanie konfiguracji";
 $access[table][4][allow_reg]    = "^reload$";
 
 $access[table][5][name]		= "manipulacja kontami uytkownikw";
-$access[table][5][allow_reg]	= "^user(add|edit|del)$";
+$access[table][5][allow_reg]	= "^(user(add|edit|del)|nodewarn|usergroup(add|edit|delete|move))$";
 
 $access[table][6][name]		= "manipulacja danymi komputerw";
-$access[table][6][allow_reg]	= "^(node(add|scan|del|edit|set)|choose(mac|ip))$";
+$access[table][6][allow_reg]	= "^(node(add|scan|del|edit|set|warn)|choose(mac|ip))$";
 
 $access[table][7][name]         = "dostp do statystyk";
 $access[table][7][allow_reg]    = "^traffic$";
