@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: adminpasswd.php,v 1.23 2004/02/21 19:38:16 lukasz Exp $
+ *  $Id: adminpasswd.php,v 1.24 2004/03/11 17:24:21 lukasz Exp $
  */
 
 $passwd = $_POST['passwd'];
@@ -48,7 +48,6 @@ if($LMS->AdminExists($id))
 	$passwd['realname'] = $LMS->GetAdminName($id);
 	$passwd['id'] = $id;
 	$layout['pagetitle'] = "Zmiana hasa dla ".$passwd['realname'];
-	$SMARTY->assign('layout',$layout);
 	$SMARTY->assign('error',$error);
 	$SMARTY->assign('passwd',$passwd);
 	$SMARTY->display('adminpasswd.html');
