@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodescan.php,v 1.14 2004/02/21 19:38:17 lukasz Exp $
+ *  $Id: nodescan.php,v 1.15 2004/03/11 17:24:22 lukasz Exp $
  */
 
 if($_GET['ownerid']&&$LMS->UserExists($_GET['ownerid']))
@@ -35,7 +35,6 @@ $SMARTY->assign('balancelist',$LMS->GetUserBalanceList($_GET['ownerid']));
 $SMARTY->assign('users',$users);
 $SMARTY->assign('nodes',$LMS->ScanNodes());
 $SMARTY->assign('userinfo',$userinfo);
-$SMARTY->assign('layout',$layout);
 
 $SMARTY->display('nodescan.html');
 
