@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,22 +21,21 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: tariffinfo.php,v 1.19 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: tariffinfo.php,v 1.21 2004/03/11 17:24:22 lukasz Exp $
  */
 
-if(!$LMS->TariffExists($_GET[id]))
+if(!$LMS->TariffExists($_GET['id']))
 {
 	header("Location: ?m=tarifflist");
 	die;
 }
-$tariff = $LMS->GetTariff($_GET[id]);
-$layout[pagetitle] = "Informacja o taryfie: ".$tariff[name];
+$tariff = $LMS->GetTariff($_GET['id']);
+$layout['pagetitle'] = "Informacja o taryfie: ".$tariff['name'];
 
-$_SESSION[backto] = $_SERVER[QUERY_STRING];
+$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
 
-$SMARTY->assign("layout",$layout);
-$SMARTY->assign("tariff",$tariff);
-$SMARTY->assign("tariffs",$LMS->GetTariffs());
-$SMARTY->display("tariffinfo.html");
+$SMARTY->assign('tariff',$tariff);
+$SMARTY->assign('tariffs',$LMS->GetTariffs());
+$SMARTY->display('tariffinfo.html');
 
 ?>
