@@ -1,6 +1,6 @@
 <?php
 
-/* LMS version 1.3.1 Maybourne
+/* LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -20,7 +20,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: traffic.php,v 1.13 2004/02/21 19:38:17 lukasz Exp $
+ *  $Id: traffic.php,v 1.14 2004/03/11 17:24:22 lukasz Exp $
  */
 
 $layout['pagetitle'] = "Statystyki wykorzystania cza";
@@ -73,7 +73,6 @@ $SMARTY->assign('startyear',$startyear);
 $SMARTY->assign('endtime',$endtime);
 $SMARTY->assign('endyear',$endyear);
 $SMARTY->assign('showips',$_POST['showips']);
-$SMARTY->assign('layout',$layout);
 $SMARTY->assign('download',$download);
 $SMARTY->assign('upload',$upload);
 $SMARTY->assign('bars',$bars);
