@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,31 +21,20 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: userbalanceok.php,v 1.16 2004/02/21 19:38:17 lukasz Exp $
+ *  $Id: userbalanceok.php,v 1.18 2004/03/11 17:24:22 lukasz Exp $
  */
 
-$layout['pagetitle'] = "Rozliczono uytkownika ID: ".sprintf("%04d",$_GET['id']);
-$SMARTY->assign('layout',$layout);
+$layout['pagetitle'] = "Rozliczenie uytkownika ID: ".sprintf("%04d",$_GET['id']);
 $SMARTY->assign('userid',$_GET['id']);
 
 if (!$LMS->UserExists($_GET['id']))
 {
 	$body = "<H1>".$layout['pagetitle']."</H1><P>Podany przez Ciebie ID jest bdny bd nie istnieje w bazie danych.</P>";
-}else{
-
-	if($_GET['is_sure']!=1)
-	{
-		$body = "<H1>".$layout['pagetitle']."</H1>";
-		$body .= "<P>Czy jeste pewien e chcesz usun uytkownika ".$LMS->GetUserName($_GET['id'])."?</P>"; 
-		$body .= "<P>Wszystkie dane uytkownika zostan utracone, a take wszystkie przypisane temu uytkownikowi komputery zostan usunite.</P>";
-		$body .= "<P><A HREF=\"?m=userdel&id=".$_GET['id']."&is_sure=1\">Tak, jestem pewien.</A></P>";
-	}else{
-		header("Location: ?m=".$_SESSION['lastmodule']);
-		$body = "<H1>".$layout['pagetitle']."</H1>";
-		$body .= "<P>Uytkownik ".$LMS->GetUserName($_GET['id'])." zosta usunity.</P>";
-		$LMS->SetBalanceZero($_GET['id']);
-	}
-		
+}
+else
+{
+	$LMS->SetBalanceZero($_GET['id']);
+	header("Location: ?m=".$_SESSION['lastmodule']);
 }
 
 $SMARTY->display('header.html');
