@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: userinfo.php,v 1.33 2004/02/21 19:38:17 lukasz Exp $
+ *  $Id: userinfo.php,v 1.36 2004/04/17 17:00:47 chilek Exp $
  */
 
 if(!eregi("^[0-9]+$",$_GET['id']))
@@ -38,6 +38,8 @@ if($LMS->UserExists($_GET['id']) == 0)
 
 $userinfo = $LMS->GetUser($_GET['id']);
 $assigments = $LMS->GetUserAssignments($_GET['id']);
+$usergroups = $LMS->UsergroupGetForUser($_GET['id']);
+$otherusergroups = $LMS->GetGroupNamesWithoutUser($_GET['id']);
 $balancelist = $LMS->GetUserBalanceList($_GET['id']);
 $usernodes = $LMS->GetUserNodes($_GET['id']);
 $tariffs = $LMS->GetTariffs();
@@ -47,13 +49,18 @@ $_SESSION['backto'] = $_SERVER['QUERY_STRING'];
 $layout['pagetitle'] = 'Informacje o uytkowniku: '.$userinfo['username'];
 
 $usernodes['ownerid'] = $_GET['id'];
-$SMARTY->assign('usernodes',$usernodes);
-$SMARTY->assign('balancelist',$balancelist);
-$SMARTY->assign('assignments',$assigments);
-$SMARTY->assign('error',$error);
-$SMARTY->assign('userinfo',$userinfo);
-$SMARTY->assign('layout',$layout);
-$SMARTY->assign('tariffs',$tariffs);
+$SMARTY->assign(
+		array(
+			'usernodes' => $usernodes,
+			'balancelist' => $balancelist,
+			'assignments' => $assigments,
+			'usergroups' => $usergroups,
+			'otherusergroups' => $otherusergroups,
+			'error' => $error,
+			'userinfo' => $userinfo,
+			'tariffs' => $tariffs
+		     )
+		);
 $SMARTY->display('userinfo.html');
 
 ?>
