@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: userlist.php,v 1.39 2004/03/26 09:05:35 alec Exp $
+ *  $Id: userlist.php,v 1.43 2004/04/27 08:47:19 alec Exp $
  */
 
 $_SESSION['backto'] = $_SERVER['QUERY_STRING'];
@@ -46,13 +46,20 @@ else
 	$n = $_GET['n'];
 $_SESSION['uln'] = $n;
 
+if(!isset($_GET['g']))
+	$g = $_SESSION['ulg'];
+else
+	$g = $_GET['g'];
+$_SESSION['ulg'] = $g;
+
 if (isset($_SESSION['ulp']) && !isset($_GET['page']))
 	$_GET['page'] = $_SESSION['ulp'];
 	    
-$userlist=$LMS->GetUserList($o, $s, $n);
+$userlist=$LMS->GetUserList($o, $s, $n, $g);
 $listdata['total'] = $userlist['total'];
-$listdata['state'] = $userlist['state'];
+$listdata['state'] = $_SESSION['uls'];;
 $listdata['network'] = $userlist['network'];
+$listdata['usergroup'] = $userlist['usergroup'];
 $listdata['order'] = $userlist['order'];
 $listdata['below'] = $userlist['below'];
 $listdata['over'] = $userlist['over'];
@@ -67,6 +74,7 @@ $_SESSION['ulp'] = $page;
 unset($userlist['total']);
 unset($userlist['state']);
 unset($userlist['network']);
+unset($userlist['usergroup']);
 unset($userlist['order']);
 unset($userlist['below']);
 unset($userlist['over']);
@@ -74,6 +82,7 @@ unset($userlist['direction']);
 $SMARTY->assign('userlist',$userlist);
 $SMARTY->assign('listdata',$listdata);
 $SMARTY->assign('networks', $LMS->GetNetworks());
+$SMARTY->assign('usergroups', $LMS->UsergroupGetAll());
 $SMARTY->assign('pagelimit',$pagelimit);
 $SMARTY->assign('page',$page);
 $SMARTY->assign('start',$start);
