@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: welcome.php,v 1.33 2004/02/21 19:38:17 lukasz Exp $
+ *  $Id: welcome.php,v 1.36 2004/03/12 06:33:44 alec Exp $
  */
 
 require_once($_LIB_DIR."/Sysinfo.class.php");
@@ -37,7 +37,6 @@ $layout['dbtype'] = $LMS->CONFIG['database']['type'];
 $SMARTY->assign('sysinfo',$SI->get_sysinfo());
 $SMARTY->assign('userstats',$LMS->UserStats());
 $SMARTY->assign('nodestats',$LMS->NodeStats());
-$SMARTY->assign('layout',$layout);
 $SMARTY->display('welcome.html');
 
 ?>
